@@ -78,9 +78,9 @@ MannKendall <- function(mydata, ...) {
 ##' @param type \code{type} determines how the data are split
 ##' i.e. conditioned, and then plotted. The default is will produce a
 ##' single plot using the entire data. Type can be one of the built-in
-##' types as detailed in \code{cutData} e.g. "season", "year",
-##' "weekday" and so on. For example, \code{type = "season"} will
-##' produce four plots --- one for each season.
+##' types as detailed in \code{cutData} e.g. \dQuote{season},
+##' \dQuote{year}, \dQuote{weekday} and so on. For example, \code{type
+##' = "season"} will produce four plots --- one for each season.
 ##'
 ##' It is also possible to choose \code{type} as another variable in
 ##' the data frame. If that variable is numeric, then the data will be
@@ -94,15 +94,15 @@ MannKendall <- function(mydata, ...) {
 ##' "weekday")} will produce a 2x2 plot split by season and day of the
 ##' week. Note, when two types are provided the first forms the
 ##' columns and the second the rows.
-##' @param avg.time Can be "month" (the default), "season" or
-##' "year". Determines the time over which data should be
-##' averaged. Note that for "year", six or more years are
-##' required. For "season" the data are plit up into spring: March,
-##' April, May etc. Note that December is considered as belonging to
-##' winter of the following year.
-##' @param statistic Statistic used for calculating monthly values. Default is
-##'   \code{"mean"}, but can also be \code{"percentile"}. See
-##'   \code{timeAverage} for more details.
+##' @param avg.time Can be \dQuote{month} (the default),
+##' \dQuote{season} or \dQuote{year}. Determines the time over which
+##' data should be averaged. Note that for \dQuote{year}, six or more
+##' years are required. For \dQuote{season} the data are split up into
+##' spring: March, April, May etc. Note that December is considered as
+##' belonging to winter of the following year.
+##' @param statistic Statistic used for calculating monthly
+##' values. Default is \dQuote{mean}, but can also be
+##' \dQuote{percentile}. See \code{timeAverage} for more details.
 ##' @param percentile Single percentile value to use if \code{statistic =
 ##'   "percentile"} is chosen.
 ##' @param data.thresh The data capture threshold to use (%) when
@@ -113,7 +113,7 @@ MannKendall <- function(mydata, ...) {
 ##' the average to be calculated, else it is recorded as
 ##' \code{NA}.
 ##' @param alpha For the confidence interval calculations of the slope. The
-##'   default is 0.05. To show 99% confidence intervals for the value of the
+##'   default is 0.05. To show 99\% confidence intervals for the value of the
 ##'   trend, choose alpha = 0.01 etc.
 ##' @param dec.place The number of decimal places to display the trend estimate
 ##'   at. The default is 2.
@@ -121,14 +121,14 @@ MannKendall <- function(mydata, ...) {
 ##' @param lab.frac Fraction along the y-axis that the trend information should
 ##'   be printed at, default 0.99.
 ##' @param lab.cex Size of text for trend information.
-##' @param x.relation This determines how the x-axis scale is plotted. "same"
-##'   ensures all panels use the same scale and "free" will use panel-specfic
-##'   scales. The latter is a useful setting when plotting data with very
-##'   different values.
-##' @param y.relation This determines how the y-axis scale is plotted. "same"
-##'   ensures all panels use the same scale and "free" will use panel-specfic
-##'   scales. The latter is a useful setting when plotting data with very
-##'   different values.
+##' @param x.relation This determines how the x-axis scale is
+##' plotted. \dQuote{same} ensures all panels use the same scale and
+##' \dQuote{free} will use panel-specfic scales. The latter is a
+##' useful setting when plotting data with very different values.
+##' @param y.relation This determines how the y-axis scale is
+##' plotted. \dQuote{same} ensures all panels use the same scale and
+##' \dQuote{free} will use panel-specfic scales. The latter is a
+##' useful setting when plotting data with very different values.
 ##' @param data.col Colour name for the data
 ##' @param line.col Colour name for the slope and uncertainty estimates
 ##' @param text.col Colour name for the slope/uncertainty numeric estimates
@@ -402,24 +402,11 @@ TheilSen <- function(mydata, pollutant = "nox", deseason = FALSE, type = "defaul
     if(!"skip" %in% names(extra.args))
         extra.args$skip <- FALSE
 
-
-    ## proper names of labelling ##############################################################################
-    pol.name <- sapply(levels(factor(split.data[ , type[1]])), function(x) quickText(x, auto.text))
-    strip <- strip.custom(factor.levels = pol.name)
-
-    if (length(type) == 1 ) {
-
-        strip.left <- FALSE
-
-    } else { ## two conditioning variables
-
-        pol.name <- sapply(levels(factor(split.data[ , type[2]])), function(x) quickText(x, auto.text))
-        strip.left <- strip.custom(factor.levels = pol.name)
-    }
-    if (length(type) == 1 & type[1] == "default") strip <- FALSE ## remove strip
-########################################################################################################
-
-
+    ## proper names of labelling ###################################################
+    strip.dat <- strip.fun(split.data, type, auto.text)
+    strip <- strip.dat[[1]]
+    strip.left <- strip.dat[[2]]
+    pol.name <- strip.dat[[3]]
 
 #### calculate slopes etc ###############################################################################
 
