@@ -60,8 +60,8 @@
 ##'   default is \code{FALSE}. Emissions activity tends to occur at local time
 ##'   e.g. rush hour is at 8 am every day. When the clocks go forward in
 ##'   spring, the emissions are effectively released into the atmosphere at BST
-##'   - 1 hour during the summer. When plotting diurnal profiles, this has the
-##'   effect of "smearing-out" the concentrations. Sometimes, a better approach
+##'   --- 1 hour during the summer. When plotting diurnal profiles, this has the
+##'   effect of \dQuote{smearing-out} the concentrations. Sometimes, a better approach
 ##'   is to express time as local time, which here is defined as BST (British
 ##'   Summer Time). This correction tends to produce better-defined diurnal
 ##'   profiles of concentration (or other variables) and allows a better
@@ -75,11 +75,12 @@
 ##' @param name.pol Names to be given to the pollutant(s). This is useful if
 ##'   you want to give a fuller description of the variables, maybe also
 ##'   including subscripts etc.
-##' @param type \code{type} determines how the data are split i.e. conditioned,
-##'   and then plotted. The default is will produce a single plot using the
-##'   entire data. Type can be one of the built-in types as detailed in
-##'   \code{cutData} e.g. "season", "year", "weekday" and so on. For example,
-##'   \code{type = "season"} will produce four plots --- one for each season.
+##' @param type \code{type} determines how the data are split
+##' i.e. conditioned, and then plotted. The default is will produce a
+##' single plot using the entire data. Type can be one of the built-in
+##' types as detailed in \code{cutData} e.g. \dQuote{season},
+##' \dQuote{year}, \dQuote{weekday} and so on. For example, \code{type
+##' = "season"} will produce four plots --- one for each season.
 ##'
 ##' It is also possible to choose \code{type} as another variable in the data
 ##'   frame. If that variable is numeric, then the data will be split into four
@@ -101,13 +102,17 @@
 ##' @param B Number of bootstrap replicates to use. Can be useful to
 ##' reduce this value when there are a large number of observations
 ##' available to increase the speed of the calculations without
-##' affecting the 95% confidence interval calculations by much.
+##' affecting the 95\% confidence interval calculations by much.
 ##' @param ci Should confidence intervals be shown? The default is \code{TRUE}.
 ##'   Setting this to \code{FALSE} can be useful if multiple pollutants are
 ##'   chosen where over-lapping confidence intervals can over complicate plots.
-##' @param cols Colours to be used for plotting. Options include "default",
-##'   "increment", "heat", "spectral", "hue" (default) and user defined (see
-##'   manual for more details).
+##' @param cols Colours to be used for plotting. Options include
+##' \dQuote{default}, \dQuote{increment}, \dQuote{heat}, \dQuote{jet}
+##' and \code{RColorBrewer} colours --- see the \code{openair}
+##' \code{openColours} function for more details. For user defined the
+##' user can supply a list of colour names recognised by R (type
+##' \code{colours()} to see the full list). An example would be
+##' \code{cols = c("yellow", "green", "blue")}
 ##' @param key By default \code{timeVariation} produces four plots on one page.
 ##'   While it is useful to see these plots together, it is sometimes necessary
 ##'   just to use one for a report. If \code{key} is \code{TRUE}, a key is
@@ -123,7 +128,7 @@
 ##' weekday plots on a Saturday, choose \code{start.day = 6}.
 ##' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If
 ##'   \code{TRUE} titles and axis labels will automatically try and format
-##'   pollutant names and units properly e.g.  by subscripting the `2' in NO2.
+##'   pollutant names and units properly e.g.  by subscripting the \sQuote{2} in NO2.
 ##' @param alpha The alpha transparency used for plotting confidence intervals.
 ##'   0 is fully transparent and 1 is opaque. The default is 0.4
 ##' @param ... Other graphical parameters passed onto \code{lattice:xyplot}
@@ -162,17 +167,17 @@
 ##' pollutant = "pm10", ylab = "pm10 (ug/m3)")
 ##'
 ##' # multiple pollutants with concentrations normalised
-##' timeVariation(mydata, pollutant = c("nox", "co"), normalise = TRUE)
+##' \dontrun{timeVariation(mydata, pollutant = c("nox", "co"), normalise = TRUE)}
 ##'
 ##' # show BST/GMT variation (see ?cutData for more details)
 ##' # the NOx plot shows the profiles are very similar when expressed in
 ##' # local time, showing that the profile is dominated by a local source
 ##' # that varies by local time and not by GMT i.e. road vehicle emissions
 ##'
-##' timeVariation(mydata, pollutant = "nox", type = "gmtbst")
+##' \dontrun{timeVariation(mydata, pollutant = "nox", type = "gmtbst")}
 ##'
 ##' ## In this case it is better to group the results for clarity:
-##' timeVariation(mydata, pollutant = "nox", group = "gmtbst")
+##' \dontrun{timeVariation(mydata, pollutant = "nox", group = "gmtbst")}
 ##'
 ##' # By contrast, a variable such as wind speed shows a clear shift when
 ##' #  expressed in local time. These two plots can help show whether the
@@ -195,12 +200,16 @@
 ##' # are important because flows of cars are approximately invariant by
 ##' # day of the week
 ##'
+##' \dontrun{
 ##' mydata <- splitByDate(mydata, dates= "1/1/2003", labels = c("before Jan. 2003", "After Jan. 2003"))
 ##' timeVariation(mydata, pollutant = "no2", group = "split.by", difference = TRUE)
+##' }
 ##'
 ##' ## sub plots can be extracted from the openair object
+##' \dontrun{
 ##' myplot <- timeVariation(mydata, pollutant = "no2")
 ##' plot(myplot, subset = "day.hour") # top weekday and plot
+##' }
 ##'
 ##' ## individual plots
 ##' ## plot(myplot, subset="day.hour") for the weekday and hours subplot (top)
@@ -305,8 +314,6 @@ alpha = 0.4, ...)  {
     if (!missing(group))  mydata <- cutData(mydata, group, ...)
     mydata <- cutData(mydata, type, ...)
 
-    mydata <- na.omit(mydata)
-
     ## title for overall and individual plots
     overall.main <- extra.args$main
     extra.args$main <- ""
