@@ -3,7 +3,19 @@ pollutionRose <- function(mydata,
                           breaks = 6, paddle = FALSE, seg = 0.9, key.position = "right",
                           ...)
 {
+
+    ## extra.args setup
+    extra.args <- list(...)
+
+    ## check to see if two met data sets are being compared.
+    ## if so, set pollutant to one of the names
+    if ("ws2" %in% names(extra.args)) {
+        pollutant <-  extra.args$ws
+        if (missing(breaks)) breaks <- NA
+    }
+
     if (is.null(breaks))  breaks <- 6
+
     if (is.numeric(breaks) & length(breaks) == 1) {
         breaks2 <- co.intervals(mydata[ , pollutant][is.finite(mydata[ ,pollutant])],
                                 number = 10, overlap = 0)
@@ -52,13 +64,25 @@ pollutionRose <- function(mydata,
 ##' By default, \code{pollutionRose} will plot a pollution rose of \code{nox}
 ##' using "wedge" style segments and placing the scale key to the right of the
 ##' plot.
-##' @usage windRose(mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type = "default",
-##'                      cols = "default", grid.line = NULL, width = 1, seg = NULL,
-##'                      auto.text = TRUE, breaks = 4, offset = 10,
-##'                      paddle = TRUE, key.header = NULL, key.footer = "(m/s)",
-##'                      key.position = "bottom", key = TRUE, dig.lab = 5,
-##'                      statistic = "prop.count", pollutant = NULL, annotate = TRUE,
-##'                      ...)
+##'
+##' It is possible to compare two wind speed-direction data sets using
+##' \code{pollutionRose}. There are many reasons for doing so e.g. to
+##' see how one site compares with another or for meteorological model
+##' evaluation. In this case, \code{ws} and \code{wd} are considered
+##' to the the reference data sets with which a second set of wind
+##' speed and wind directions are to be compared (\code{ws2} and
+##' \code{wd2}). The second set of values is subtracted from the first
+##' and the differences compared. If for example, \code{wd2} was
+##' biased positive compared with \code{wd} then \code{pollutionRose}
+##' will show the bias in polar coordinates. In its default use, wind
+##' direction bias is colour-coded to show negative bias in one colour
+##' and positive bias in another.
+##'
+##' @usage windRose(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA, ws.int = 2, angle = 30,
+##' type = "default", cols = "default", grid.line = NULL, width = 1, seg = NULL,
+##' auto.text = TRUE, breaks = 4, offset = 10, paddle = TRUE, key.header = NULL,
+##' key.footer = "(m/s)", key.position = "bottom", key = TRUE, dig.lab = 5,
+##' statistic = "prop.count", pollutant = NULL, annotate = TRUE, border = NA, ...)
 ##'
 ##'
 ##'     pollutionRose(mydata, pollutant = "nox", key.footer = pollutant,
@@ -70,18 +94,21 @@ pollutionRose <- function(mydata,
 ##' @param mydata A data frame containing fields \code{ws} and \code{wd}
 ##' @param ws Name of the column representing wind speed.
 ##' @param wd Name of the column representing wind direction.
+##' @param ws2 The user can supply a second set of wind speed and wind direction values with which the first can be compared. See details below for full explanation.
+##' @param wd2 see \code{ws2}.
 ##' @param ws.int The Wind speed interval. Default is 2 m/s but for low met
 ##'   masts with low mean wind speeds a value of 1 or 0.5 m/s may be better.
 ##'   Note, this argument is superseded in \code{pollutionRose}. See
 ##'   \code{breaks} below.
-##' @param angle Default angle of "spokes" is 30. Other potentially useful
+##' @param angle Default angle of \dQuote{spokes} is 30. Other potentially useful
 ##'   angles are 45 and 10. Note that the width of the wind speed interval may
 ##'   need adjusting using \code{width}.
-##' @param type \code{type} determines how the data are split i.e. conditioned,
-##'   and then plotted. The default is will produce a single plot using the
-##'   entire data. Type can be one of the built-in types as detailed in
-##'   \code{cutData} e.g. "season", "year", "weekday" and so on. For example,
-##'   \code{type = "season"} will produce four plots --- one for each season.
+##' @param type \code{type} determines how the data are split
+##' i.e. conditioned, and then plotted. The default is will produce a
+##' single plot using the entire data. Type can be one of the built-in
+##' types as detailed in \code{cutData} e.g. \dQuote{season},
+##' \dQuote{year}, \dQuote{weekday} and so on. For example, \code{type
+##' = "season"} will produce four plots --- one for each season.
 ##'
 ##' It is also possible to choose \code{type} as another variable in the data
 ##'   frame. If that variable is numeric, then the data will be split into four
@@ -94,10 +121,11 @@ pollutionRose <- function(mydata,
 ##'   produce a 2x2 plot split by season and day of the week. Note, when two
 ##'   types are provided the first forms the columns and the second the rows.
 ##' @param cols Colours to be used for plotting. Options include
-##'   \code{default}, \code{increment}, \code{heat}, \code{jet}, \code{hue} and
-##'   user defined. For user defined the user can supply a list of colour names
-##'   recognised by R (type \code{colours()} to see the full list). An example
-##'   would be \code{cols = c("yellow", "green", "blue", "black")}.
+##' \dQuote{default}, \dQuote{increment}, \dQuote{heat}, \dQuote{jet},
+##' \dQuote{hue} and user defined. For user defined the user can
+##' supply a list of colour names recognised by R (type
+##' \code{colours()} to see the full list). An example would be
+##' \code{cols = c("yellow", "green", "blue", "black")}.
 ##' @param grid.line Grid line interval to use. If \code{NULL}, as in default,
 ##'   this is assigned by \code{windRose} based on the available data range.
 ##'   However, it can also be forced to a specific value, e.g.
@@ -109,8 +137,9 @@ pollutionRose <- function(mydata,
 ##' width of the segments. For example, \code{seg = 0.5} will produce
 ##' segments 0.5 * \code{angle}.
 ##' @param auto.text Either \code{TRUE} (default) or \code{FALSE}. If
-##'   \code{TRUE} titles and axis labels will automatically try and format
-##'   pollutant names and units properly e.g.  by subscripting the `2' in NO2.
+##' \code{TRUE} titles and axis labels will automatically try and
+##' format pollutant names and units properly e.g.  by subscripting
+##' the \sQuote{2} in NO2.
 ##' @param breaks Most commonly, the number of break points for wind speed in
 ##'   \code{windRose} or pollutant in \code{pollutionRose}. For \code{windRose}
 ##'   and the \code{ws.int} default of 2 m/s, the default, 4, generates the
@@ -131,25 +160,27 @@ pollutionRose <- function(mydata,
 ##' \code{drawOpenKey} via \code{quickText}, applying the auto.text
 ##' argument, to handle formatting.
 ##' @param key.footer see \code{key.footer}.
-##' @param key.position Location where the scale key is to plotted.  Allowed
-##'   arguments currently include \code{"top"}, \code{"right"}, \code{"bottom"}
-##'   and \code{"left"}.
+##' @param key.position Location where the scale key is to plotted.
+##' Allowed arguments currently include \dQuote{top},
+##' \dQuote{right}, \dQuote{bottom} and \dQuote{left}.
 ##' @param key Fine control of the scale key via \code{drawOpenKey}. See
 ##'   \code{drawOpenKey} for further details.
 ##' @param dig.lab The number of signficant figures at which scientific number
 ##'   formatting is used in break point and key labelling. Default 5.
-##' @param statistic The \code{statistic} to be applied to each data bin in the
-##'   plot. Options currently include \code{"prop.count"},
-##'   \code{"prop.mean"} and \code{"abs.count"}. The default \code{"prop.count"}
-##'   sizes bins according to the proportion of the frequency of measurements.
-##'   Similarly, \code{prop.mean} sizes bins according to their relative contribution
-##'   to the mean. \code{"abs.count"} provides the absolute count of measurements
-##'   in each bin.
+##' @param statistic The \code{statistic} to be applied to each data
+##' bin in the plot. Options currently include \dQuote{prop.count},
+##' \dQuote{prop.mean} and \dQuote{abs.count}. The default
+##' \dQuote{prop.count} sizes bins according to the proportion of
+##' the frequency of measurements.  Similarly, \dQuote{prop.mean} sizes
+##' bins according to their relative contribution to the
+##' mean. \dQuote{abs.count} provides the absolute count of
+##' measurements in each bin.
 ##' @param pollutant Alternative data series to be sampled instead of wind
 ##'   speed. The \code{windRose} default NULL is equivalent to \code{pollutant
 ##'   = "ws"}.
 ##' @param annotate If \code{TRUE} then the percentage calm and mean values are
 ##'   printed in each panel.
+##' @param border Border colour for shaded areas. Default is no border.
 ##' @param ... For \code{pollutionRose} other parameters that are
 ##' passed on to \code{windRose}. For \code{windRose} other parameters
 ##' that are passed on to \code{drawOpenKey}, \code{lattice:xyplot}
@@ -160,13 +191,14 @@ pollutionRose <- function(mydata,
 ##' @export windRose pollutionRose
 ##' @import plyr
 ##' @return As well as generating the plot itself, \code{windRose} and
-##'   \code{pollutionRose} also return an object of class ``openair''. The
-##'   object includes three main components: \code{call}, the command used to
-##'   generate the plot; \code{data}, the data frame of summarised information
-##'   used to make the plot; and \code{plot}, the plot itself. If retained,
-##'   e.g. using \code{output <- windRose(mydata)}, this output can be used to
-##'   recover the data, reproduce or rework the original plot or undertake
-##'   further analysis.
+##' \code{pollutionRose} also return an object of class
+##' \dQuote{openair}. The object includes three main components:
+##' \code{call}, the command used to generate the plot; \code{data},
+##' the data frame of summarised information used to make the plot;
+##' and \code{plot}, the plot itself. If retained, e.g. using
+##' \code{output <- windRose(mydata)}, this output can be used to
+##' recover the data, reproduce or rework the original plot or
+##' undertake further analysis.
 ##'
 ##' An openair output can be manipulated using a number of generic operations,
 ##'   including \code{print}, \code{plot} and \code{summarise}. See
@@ -200,7 +232,9 @@ pollutionRose <- function(mydata,
 ##' windRose(mydata,type = "year")
 ##'
 ##' # windRose in 10 degree intervals with gridlines and width adjusted
+##' \dontrun{
 ##' windRose(mydata, angle = 10, width = 0.2, grid.line = 1)
+##' }
 ##'
 ##' # pollutionRose of nox
 ##' pollutionRose(mydata, pollutant = "nox")
@@ -210,13 +244,25 @@ pollutionRose <- function(mydata,
 ##' pollutionRose(mydata, pollutant = "pm10", type = "year", statistic = "prop.mean")
 ##' }
 ##'
+##' ## example of comparing 2 met sites
+##' ## first we will make some new ws/wd data with a postive bias
+##' mydata$ws2 = mydata$ws + 2 * rnorm(nrow(mydata)) + 1
+##' mydata$wd2 = mydata$wd + 30 * rnorm(nrow(mydata)) + 30
 ##'
-windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type = "default",
+##' ## need to correct negative wd
+##' id <- which(mydata$wd2 < 0)
+##' mydata$wd2[id] <- mydata$wd2[id] + 360
+##'
+##' ## results show postive bias in wd and ws
+##' pollutionRose(mydata, ws = "ws", wd = "wd", ws2 = "ws2", wd2 = "wd2")
+windRose <- function (mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA, ws.int = 2,
+                      angle = 30, type = "default",
                       cols = "default", grid.line = NULL, width = 1, seg = NULL,
                       auto.text = TRUE, breaks = 4, offset = 10,
                       paddle = TRUE, key.header = NULL, key.footer = "(m/s)",
                       key.position = "bottom", key = TRUE, dig.lab = 5,
                       statistic = "prop.count", pollutant = NULL, annotate = TRUE,
+                      border = NA,
                       ...)
 {
 
@@ -247,24 +293,24 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
         angle <- 3
     }
 
-    ##extra.args setup
+    ## extra.args setup
     extra.args <- list(...)
 
-    #label controls
+                                        #label controls
     extra.args$xlab <- if("xlab" %in% names(extra.args))
-                           quickText(extra.args$xlab, auto.text) else quickText("", auto.text)
+        quickText(extra.args$xlab, auto.text) else quickText("", auto.text)
     extra.args$ylab <- if("ylab" %in% names(extra.args))
-                           quickText(extra.args$ylab, auto.text) else quickText("", auto.text)
+        quickText(extra.args$ylab, auto.text) else quickText("", auto.text)
     extra.args$main <- if("main" %in% names(extra.args))
-                           quickText(extra.args$main, auto.text) else quickText("", auto.text)
+        quickText(extra.args$main, auto.text) else quickText("", auto.text)
 
-    ## statistics setup
+    ## preset statitistics
 
-    # preset statitistics
-    if(is.character(statistic)){
-        #allowed cases
-        allowed.statistics <- c("prop.count", "prop.mean", "abs.count", "frequency")
-        if (!is.character(statistic) || !statistic[1] %in% allowed.statistics) {
+    if (is.character(statistic)) {
+        ## allowed cases
+        ok.stat <- c("prop.count", "prop.mean", "abs.count", "frequency")
+
+        if (!is.character(statistic) || !statistic[1] %in% ok.stat) {
             warning("In windRose(...):\n  statistic unrecognised",
                     "\n  enforcing statistic = 'prop.count'", call. = FALSE)
             statistic <- "prop.count"
@@ -302,15 +348,16 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
 
     }
 
-    if(is.list(statistic)) {
+    if (is.list(statistic)) {
 
-    #IN DEVELOPMENT
+        ## IN DEVELOPMENT
+
+        ## this section has no testing/protection
+        ## but allows users to supply a function
+        ## scale it by total data or panel
+        ## convert proportions to percentage
+        ## label it
 
-    #this section has no testing/protection
-    #but allows users to supply a function
-    #scale it by total data or panel
-    #convert proportions to percentage
-    #label it
         stat.fun <- statistic$fun
         stat.unit <- statistic$unit
         stat.scale <- statistic$scale
@@ -320,22 +367,51 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
         stat.labcalm <- statistic$labcalm
     }
 
-
+    ## variables we need
     vars <- c(wd, ws)
-    if (any(type %in%  openair:::dateTypes)) vars <- c(vars, "date")
 
-    if (!is.null(pollutant)) {
-        vars <- c(vars, pollutant)
+    diff <- FALSE ## i.e. not two sets of ws/wd
+    rm.neg <- TRUE ## will remove negative ws in check.prep
+
+    ## case where two met data sets are to be compared
+    if (!is.na(ws2) & !is.na(wd2)) {
+        vars <- c(vars, ws2, wd2)
+        diff <- TRUE
+        rm.neg <- FALSE
+        mydata$ws <- mydata[, ws2] - mydata[, ws]
+        mydata$wd <- mydata[, wd2] - mydata[, wd]
+
+        ## fix negative wd
+        id <- which(mydata$wd < 0)
+        if (length(id) > 0) mydata$wd[id] <- mydata$wd[id] + 360
+
+        pollutant <- "ws"
+        key.footer <- "ws"
+        wd <- "wd" ; ws <- "ws"
+        vars <- c("ws", "wd")
+        if (missing(angle)) angle <- 10
+        if (missing(offset)) offset <- 20
+        ## set the breaks to cover all the data
+        if (is.na(breaks[1])) {
+            max.br <- max(ceiling(abs(c(min(mydata$ws, na.rm = TRUE), max(mydata$ws, na.rm = TRUE)))))
+            breaks <- c(-1 * max.br, 0, max.br)
+        }
+
+        if (missing(cols)) cols <- c("lightskyblue", "tomato")
+        seg <- 1
     }
-    mydata <- openair:::checkPrep(mydata, vars, type, remove.calm = FALSE)
+
+    if (any(type %in% openair:::dateTypes)) vars <- c(vars, "date")
+
+    if (!is.null(pollutant)) vars <- c(vars, pollutant)
+
+    mydata <- openair:::checkPrep(mydata, vars, type, remove.calm = FALSE, remove.neg = rm.neg)
 
     mydata <- na.omit(mydata)
 
-    if (is.null(pollutant))
-        pollutant <- ws
-    mydata$.z.poll <- mydata[, pollutant]
+    if (is.null(pollutant)) pollutant <- ws
 
-    ## if (type == "ws")  type <- "ws.1"
+    mydata$x <- mydata[, pollutant]
 
     mydata[ , wd] <- angle * ceiling(mydata[ , wd] / angle - 0.5)
     mydata[ , wd][mydata[ , wd] == 0] <- 360
@@ -346,65 +422,74 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
 
     if (length(breaks) == 1) breaks <- 0:(breaks - 1) * ws.int
 
-    if (max(breaks) < max(mydata$.z.poll, na.rm = TRUE)) breaks <- c(breaks, max(mydata$.z.poll, na.rm = TRUE))
+    if (max(breaks) < max(mydata$x, na.rm = TRUE)) breaks <- c(breaks, max(mydata$x, na.rm = TRUE))
 
-    if (min(breaks) > min(mydata$.z.poll, na.rm = TRUE)) breaks <- c(min(mydata$.z.poll, na.rm = TRUE), breaks)
+    if (min(breaks) > min(mydata$x, na.rm = TRUE)) breaks <- c(min(mydata$x, na.rm = TRUE), breaks)
 
     breaks <- unique(breaks)
-    mydata$.z.poll <- cut(mydata$.z.poll, breaks = breaks, include.lowest = FALSE,
-                          dig.lab = dig.lab)
+    mydata$x <- cut(mydata$x, breaks = breaks, include.lowest = FALSE,
+                    dig.lab = dig.lab)
 
-    theLabels <- gsub("[(]|[)]|[[]|[]]", "", levels(mydata$.z.poll))
-    theLabels <- gsub("[,]", "-", theLabels)
+    ## clean up cut intervals
+    theLabels <- gsub("[(]|[)]|[[]|[]]", "", levels(mydata$x))
+    theLabels <- gsub("[,]", " to ", theLabels)
 
-    ######################
     ## statistic handling
-    #####################
 
     prepare.grid <- function(mydata) {
 
-        levels(mydata$.z.poll) <- c(paste(".z.poll", 1:length(theLabels),
-                                          sep = ""))
+        levels(mydata$x) <- c(paste("x", 1:length(theLabels), sep = ""))
 
         all <- stat.fun(mydata[ , wd])
         calm <- mydata[mydata[ , wd] == -999, ][, pollutant]
         mydata <- mydata[mydata[ , wd] != -999, ]
-        mydata <- na.omit(mydata) # needed?
 
         calm <- stat.fun(calm)
-        weights <- tapply(mydata[, pollutant], list(mydata[ , wd], mydata$.z.poll),
-                              stat.fun)
 
-        #scaling
-        if (stat.scale == "all"){
-              calm <- calm / all
-              weights <- weights / all
+        weights <- tapply(mydata[, pollutant], list(mydata[ , wd], mydata$x),
+                          stat.fun)
+
+        ## scaling
+        if (stat.scale == "all") {
+            calm <- calm / all
+            weights <- weights / all
         }
-        if (stat.scale == "panel"){
-              temp <- stat.fun(stat.fun(weights)) + calm
-              calm <- calm / temp
-              weights <- weights / temp
+
+        if (stat.scale == "panel") {
+            temp <- stat.fun(stat.fun(weights)) + calm
+            calm <- calm / temp
+            weights <- weights / temp
         }
 
         weights[is.na(weights)] <- 0
         weights <- t(apply(weights, 1, cumsum))
 
-        if (stat.scale=="all" | stat.scale=="panel"){
+        if (stat.scale == "all" | stat.scale == "panel"){
             weights <- weights * 100
             calm <- calm * 100
         }
 
         panel.fun <- stat.fun2(mydata[ , pollutant])
 
+        ## calculate mean wd - useful for cases comparing two met data sets
+        u <- mean(sin(2 * pi * mydata$wd / 360))
+        v <- mean(cos(2 * pi * mydata$wd / 360))
+        mean.wd <- atan2(u, v) * 360 / 2 / pi
+        if (mean.wd < 0) mean.wd <- mean.wd + 360
+        ## show as a negative (bias)
+        if (mean.wd > 180) mean.wd <- mean.wd - 360
+
+
         weights <- cbind(data.frame(weights), wd = as.numeric(row.names(weights)),
-                         calm = calm, panel.fun = panel.fun)
+                         calm = calm, panel.fun = panel.fun, mean.wd = mean.wd)
 
         weights
     }
 
     if (paddle) {
-        poly <- function(wd, len1, len2, width, colour, x.off = 0,
-                         y.off = 0) {
+
+        poly <- function(wd, len1, len2, width, colour, x.off = 0, y.off = 0) {
+
             theta <- wd * pi / 180
             len1 <- len1 + off.set
             len2 <- len2 + off.set
@@ -417,10 +502,10 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
             y3 <- len2 * cos(theta) + width * sin(theta) + y.off
             y4 <- len2 * cos(theta) - width * sin(theta) + y.off
             lpolygon(c(x1, x2, x4, x3), c(y1, y2, y4, y3), col = colour,
-                     border = NA)
+                     border = border)
         }
-    } else {
 
+    } else {
 
         poly <- function(wd, len1, len2, width, colour, x.off = 0,
                          y.off = 0) {
@@ -431,12 +516,12 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
             theta <- seq((wd - seg * angle / 2), (wd + seg * angle / 2),
                          length.out = (angle - 2) * 10)
             theta <- ifelse(theta < 1, 360 - theta, theta)
-            theta <- theta * pi/180
+            theta <- theta * pi / 180
             x1 <- len1 * sin(theta) + x.off
             x2 <- rev(len2 * sin(theta) + x.off)
             y1 <- len1 * cos(theta) + x.off
             y2 <- rev(len2 * cos(theta) + x.off)
-            lpolygon(c(x1, x2), c(y1, y2), col = colour, border = NA)
+            lpolygon(c(x1, x2), c(y1, y2), col = colour, border = border)
         }
     }
 
@@ -444,112 +529,132 @@ windRose <- function (mydata, ws = "ws", wd = "wd", ws.int = 2, angle = 30, type
 
     results.grid <- ddply(mydata, type, prepare.grid)
 
-    #format
+    ## format
     results.grid$calm <- stat.labcalm(results.grid$calm)
-    ## proper names of labelling ##############################################################################
-    pol.name <- sapply(levels(results.grid[ , type[1]]),
-                       function(x) quickText(x, auto.text))
-    strip <- strip.custom(factor.levels = pol.name)
+    results.grid$mean.wd <- stat.labcalm(results.grid$mean.wd)
 
-    if (length(type) == 1 ) {
+    ## proper names of labelling ###################################################
+    strip.dat <- openair:::strip.fun(results.grid, type, auto.text)
+    strip <- strip.dat[[1]]
+    strip.left <- strip.dat[[2]]
+    pol.name <- strip.dat[[3]]
 
-        strip.left <- FALSE
-
-    } else { ## two conditioning variables
-
-        pol.name <- sapply(levels(results.grid[ , type[2]]),
-                           function(x) quickText(x, auto.text))
-        strip.left <- strip.custom(factor.levels = pol.name)
+    if (length(theLabels) < length(cols)) {
+        col <- cols[1:length(theLabels)]
+    } else {
+        col <- openColours(cols, length(theLabels))
     }
-    if (length(type) == 1 & type[1] == "default") strip <- FALSE ## remove strip
 
-###############################################################################
-
-    col <- openColours(cols, length(theLabels))
     max.freq <- max(results.grid[, (length(type) + 1) : (length(theLabels) +
                                                          length(type))], na.rm = TRUE)
     off.set <- max.freq * (offset / 100)
     box.widths <- seq(0.002 ^ 0.25, 0.016 ^ 0.25, length.out = length(theLabels)) ^ 4
     box.widths <- box.widths * max.freq * angle / 5
 
-    #key, colorkey, legend
+    ## key, colorkey, legend
     legend <- list(col = col, space = key.position, auto.text = auto.text,
                    labels = theLabels, footer = key.footer, header = key.header,
                    height = 0.60, width = 1.5, fit = "scale",
-                   plot.style = if(paddle) "paddle"  else "other")
+                   plot.style = if (paddle) "paddle" else "other")
     legend <- openair:::makeOpenKeyLegend(key, legend, "windRose")
 
 
     temp <- paste(type, collapse = "+")
-    myform <- formula(paste(".z.poll1 ~ wd | ", temp, sep = ""))
+    myform <- formula(paste("x1 ~ wd | ", temp, sep = ""))
 
     mymax <- 2 * max.freq
-    myby <- if(is.null(grid.line))
-                 pretty(c(0, mymax), 10)[2] else grid.line
+    myby <- if (is.null(grid.line)) pretty(c(0, mymax), 10)[2] else grid.line
 
-    ###########
-    #rethink next bit?
-    #error catcher for users setting too big grid.line
-    ##########
-    if(myby / mymax > 0.9)
-          myby <- mymax * 0.9
+    if (myby / mymax > 0.9) myby <- mymax * 0.9
 
-
-    #xyplot handling
     xyplot.args <- list(x = myform,
-                  xlim = 1.03 * c(-max.freq - off.set, max.freq + off.set),
-                  ylim = 1.03 * c(-max.freq - off.set, max.freq + off.set),
-                  data = results.grid,
-                  type = "n",
-                  sub = stat.lab,
-                  strip = strip,
-                  strip.left = strip.left,
-                  as.table = TRUE,
-                  aspect = 1,
-                  par.strip.text = list(cex = 0.8),
-                  scales = list(draw = FALSE),
+                        xlim = 1.03 * c(-max.freq - off.set, max.freq + off.set),
+                        ylim = 1.03 * c(-max.freq - off.set, max.freq + off.set),
+                        data = results.grid,
+                        type = "n",
+                        sub = stat.lab,
+                        strip = strip,
+                        strip.left = strip.left,
+                        as.table = TRUE,
+                        aspect = 1,
+                        par.strip.text = list(cex = 0.8),
+                        scales = list(draw = FALSE),
 
-                  panel = function(x, y, subscripts, ...) {
-                      panel.xyplot(x, y, ...)
-                      angles <- seq(0, 2 * pi, length = 360)
-                      sapply(seq(off.set, mymax, by = myby),
-                             function(x) llines(x * sin(angles), x * cos(angles),
-                                                col = "grey85", lwd = 1))
+                        panel = function(x, y, subscripts, ...) {
+                            panel.xyplot(x, y, ...)
+                            angles <- seq(0, 2 * pi, length = 360)
+                            sapply(seq(off.set, mymax, by = myby),
+                                   function(x) llines(x * sin(angles), x * cos(angles),
+                                                      col = "grey85", lwd = 1))
 
-                      subdata <- results.grid[subscripts, ]
+                            subdata <- results.grid[subscripts, ]
+                            upper <- max.freq + off.set
 
-                      for (i in 1:nrow(subdata)) {
-                          with(subdata, {
-                              for (j in 1:length(theLabels)) {
-                                  if (j == 1) {
-                                      temp <- "poly(wd[i], 0, .z.poll1[i], width * box.widths[1], col[1])"
-                                  }
-                                  else {
-                                      temp <- paste("poly(wd[i], .z.poll", j -
-                                                    1, "[i], .z.poll", j, "[i], width * box.widths[",
-                                                    j, "], col[", j, "])", sep = "")
-                                  }
-                                  eval(parse(text = temp))
-                              }
-                          })
-                      }
+                            ## add axis lines
+                            larrows(-upper, 0, upper, 0, code = 3, length = 0.1)
+                            larrows(0, -upper, 0, upper, code = 3, length = 0.1)
 
-                  ltext(seq((myby + off.set), mymax,
-                      myby) * sin(pi/4), seq((myby +
-                      off.set), mymax, myby) * cos(pi / 4),
-                      paste(seq(myby, mymax, by = myby), stat.unit,
-                      sep = ""), cex = 0.7)
+                            ltext(upper * -1 * 0.95, 0.07 * upper, "W", cex = 0.7)
+                            ltext(0.07 * upper, upper * -1 * 0.95, "S", cex = 0.7)
+                            ltext(0.07 * upper, upper * 0.95, "N", cex = 0.7)
+                            ltext(upper * 0.95, 0.07 *upper, "E", cex = 0.7)
 
-                  if (annotate)
-                      ltext(max.freq, -max.freq, label = paste(stat.lab2, " = ",
-                          subdata$panel.fun[1], "\ncalm = ", subdata$calm[1], stat.unit,
-                          sep = ""), adj = c(1, 0), cex = 0.7, col = calm.col)
-                  }, legend = legend)
+                            if (nrow(subdata) > 0) {
 
-    #reset for extra.args
+                                for (i in 1:nrow(subdata)) { ## go through wind angles 30, 60, ...
+                                    with(subdata, {
+                                        for (j in 1:length(theLabels)) { ## go through paddles x1, x2, ...
+                                            if (j == 1) {
+
+                                                temp <- "poly(wd[i], 0, x1[i], width * box.widths[1], col[1])"
+
+                                            } else {
+
+                                                temp <- paste("poly(wd[i], x", j - 1,
+                                                              "[i], x", j, "[i], width * box.widths[",
+                                                              j, "], col[", j, "])", sep = "")
+
+                                            }
+                                            eval(parse(text = temp))
+                                        }
+                                    })
+                                }
+
+                            }
+
+                            ltext(seq((myby + off.set), mymax, myby) * sin(pi / 4),
+                                  seq((myby + off.set), mymax, myby) * cos(pi / 4),
+                                  paste(seq(myby, mymax, by = myby), stat.unit,  sep = ""), cex = 0.7)
+
+                            ## annotations e.g. calms, means etc
+                            if (annotate) ## don't add calms for prop.mean for now...
+                                if (statistic != "prop.mean") {
+                                    if (!diff) {
+                                        ltext(max.freq + off.set, -max.freq - off.set,
+                                              label = paste(stat.lab2, " = ",
+                                              subdata$panel.fun[1], "\ncalm = ",
+                                              subdata$calm[1], stat.unit, sep = ""),
+                                              adj = c(1, 0), cex = 0.7, col = calm.col)
+                                    }
+                                    if (diff) { ## when two data sets are present
+                                        ltext(max.freq + off.set, -max.freq - off.set,
+                                              label = paste("mean ws = ",
+                                              round(subdata$panel.fun[1], 1),
+                                              "\nmean wd = ", round(subdata$mean.wd[1], 1),
+                                              sep = ""), adj = c(1, 0), cex = 0.7, col = calm.col)
+                                    }
+                                } else {
+                                    ltext(max.freq + off.set, -max.freq - off.set,
+                                          label = paste(stat.lab2, " = ", subdata$panel.fun[1],
+                                          stat.unit, sep = ""), adj = c(1, 0), cex = 0.7,
+                                          col = calm.col)
+                                }
+                        }, legend = legend)
+
+    ## reset for extra.args
     xyplot.args <- openair:::listUpdate(xyplot.args, extra.args)
 
-    #plot
+    ## plot
     plt <- do.call(xyplot, xyplot.args)
 
 
